@@ -1,4 +1,6 @@
 pub mod character_recognition;
 pub mod int_to_ascii;
 pub mod md5;
+pub mod parse_lines;
 pub mod permutation;
+pub use parse_lines::parse_lines;
