@@ -73,7 +73,7 @@ pub fn solve(input: &mut Input) -> Result<u32, String> {
 
 #[test]
 fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     let real_input = include_str!("day15_input.txt");
     test_part_one!(real_input => 597);
