@@ -62,7 +62,7 @@ pub fn solve(input: &mut Input) -> Result<Word, String> {
 
 #[test]
 pub fn test() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
     let input = include_str!("day23_input.txt");
     test_part_one!(input => 16549);
     test_part_two!(input => 11462);
